TextStylesManager class

Constructors

TextStylesManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getMediumStyle({double fontSize = s16, required Color color}) TextStyle
getRegularStyle({double fontSize = s14, required Color color}) TextStyle

Constants

s14 → const double
s16 → const double
s18 → const double