features/context_menu/presentation/widget/context_menu_wrapper library

Classes

ContextMenuWrapper
A wrapper widget that simplifies the usage of the context menu. It listens for a long press and automatically shows the menu.