context_menu_android library
Classes
- ContextMenuItem
- Represents an action in the context menu.
- ContextMenuWrapper
- A wrapper widget that simplifies the usage of the context menu. It listens for a long press and automatically shows the menu.
Enums
- IconPosition
- Defines the position of the icon relative to the label in a context menu item.